@@ -1,6 +1,7 @@
 from typing import *
 import royalnet
 import royalnet.commands as rc
+import royalnet.utils as ru
 import random
 import datetime
 
@@ -58,16 +59,21 @@ class FortuneCommand(rc.Command):
         "🔙 Oggi torneai indietro nel tempo!",
         "🚨 Oggi suonerà l'allarme della Velvet Room!",
         "♾ Oggi ti sembrerà infinito!",
+        "👹 Oggi perfino i demoni avranno paura di te!",
+        "🥐 Oggi mangerai una brioche (o lancerai un boomerang)!",
     ]
 
     async def run(self, args: rc.CommandArgs, data: rc.CommandData) -> None:
         async with data.session_acm() as session:
             author = await data.find_author(session=session, required=True)
-        today = datetime.date.today()
+            if author.trionfistatus and author.trionfistatus.zero:
+                author.trionfistatus.x = datetime.datetime.now()
 
-        h = author.uid * hash(today)
+            today = datetime.date.today()
 
-        r = random.Random(x=h)
+            h = author.uid * hash(today)
 
-        message = r.sample(self._fortunes, 1)[0]
-        await data.reply(message)
+            r = random.Random(x=h)
+
+            message = r.sample(self._fortunes, 1)[0]
+            await data.reply(message)
