@@ -15,6 +15,7 @@ from .api_user_avatar import ApiUserAvatarStar
 from .api_auth_login_osu import ApiAuthLoginOsuStar
 from .api_diario_range import ApiDiarioRangeStar
 from .api_diario_latest import ApiDiarioLatestStar
+from ..halloween2020.api_user_trionfi import ApiUserTrionfiStar
 
 # Enter the PageStars of your Pack here!
 available_page_stars = [
@@ -34,6 +35,7 @@ available_page_stars = [
     ApiAuthLoginOsuStar,
     ApiDiarioRangeStar,
     ApiDiarioLatestStar,
+    ApiUserTrionfiStar,
 ]
 
 # Don't change this, it should automatically generate __all__
