@@ -41,6 +41,6 @@ class ApiUserRygStar(rca.ApiStar):
             "steam": [steam.json() for steam in user.steam],
             "leagueoflegends": [leagueoflegends.json() for leagueoflegends in user.leagueoflegends],
             "osu": [osu.json() for osu in user.osu],
-            "trivia": user.trivia_score.json() if user.trivia_score is not None else None
+            "trivia": user.trivia_score.json() if user.trivia_score is not None else None,
         }
         return result
