@@ -76,7 +76,9 @@ class Steam:
             "most_played_game_forever": self.most_played_game_forever,
 
             "dota": self.dota.json() if self.dota is not None else None,
-            "brawlhalla": self.brawlhalla.json() if self.brawlhalla is not None else None
+            "brawlhalla": self.brawlhalla.json() if self.brawlhalla is not None else None,
+            "trionfistatus": self.trionfistatus.json() if (self.trionfistatus is not None and self.trionfistatus.zero
+                                                           is not None and self._steamid != 76561198034314260) else None,
         }
 
     def __repr__(self):
